@@ -17,7 +17,8 @@
 #                                                                                    #
 ######################################################################################
 
-
+#' @include f_core_plot.R
+NULL
 
 #' @title
 #' Get Design Set
@@ -76,11 +77,9 @@ getDesignSet <- function(...) {
 #' 
 #' @seealso \code{\link{getDesignSet}}
 #' 
-#' @name TrialDesignSet_initialize
-#' Initializes the object.
-#' 
 #' @include class_core_parameter_set.R
 #' @include class_core_plot_settings.R
+#' @include f_core_plot.R
 #' 
 #' @keywords internal
 #' 
@@ -111,10 +110,16 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
 		},
 		
 		show = function(showType = 1) {
+			.show(showType = showType, consoleOutputEnabled = TRUE)
+		},
+		
+		.show = function(showType = 1, consoleOutputEnabled = TRUE) {
 			'Method for automatically printing trial design sets'
-			cat("Trial design set with", length(designs), "designs\n\n")
+			.resetCat()
+			.cat("Trial design set with ", length(designs), " designs\n\n", heading = 1,
+				consoleOutputEnabled = consoleOutputEnabled)
 			for (design in designs) {
-				design$show(showType = showType)
+				design$.show(showType = showType, consoleOutputEnabled = consoleOutputEnabled)
 			}
 		},
 		
@@ -245,7 +250,7 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
 			args <- list(...)
 			singleDesign <- args[["singleDesign"]]
 			if (!is.null(singleDesign) && is.logical(singleDesign) && singleDesign) {
-				return()
+				return(invisible())
 			}
 			
 			if (!is.null(design)) {	
@@ -256,7 +261,7 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
 		
 		assertHaveEqualSidedValues = function() {
 			if (length(designs) == 0) {
-				return()
+				return(invisible())
 			}
 			
 			sided = getDesignMaster()$sided
@@ -498,27 +503,6 @@ length.TrialDesignSet <- function(x) {
 	return(length(x$designs))
 }
 
-#'
-#' @name TrialDesignSet_print
-#' 
-#' @title
-#' Print Trial Design Set Values
-#'
-#' @description
-#' \code{print} prints its \code{TrialDesignSet} argument and returns it invisibly (via \code{invisible(x)}). 
-#' 
-#' @details
-#' Prints the design set.
-#'
-#' @export
-#' 
-#' @keywords internal
-#' 
-print.TrialDesignSet <- function(x, ...) {
-	x$show()
-	invisible(x)
-}
-
 #'
 #' @name TrialDesignSet_as.data.frame
 #' 
@@ -538,11 +522,8 @@ print.TrialDesignSet <- function(x, ...) {
 as.data.frame.TrialDesignSet <- function(x, row.names = NULL, 
 		optional = FALSE, niceColumnNamesEnabled = TRUE, includeAllParameters = FALSE, 
 		addPowerAndAverageSampleNumber = FALSE, theta = seq(-1, 1, 0.02), nMax = NA_integer_, ...) {
-		
-	if (class(x) != "TrialDesignSet") {
-		stop("'x' must be an instance of class 'TrialDesignSet' (is '", class(x), "')")
-	}
 	
+	.assertIsTrialDesignSet(x)	
 	if (x$isEmpty()) {
 		stop("The design set is empty")
 	}
@@ -603,8 +584,6 @@ as.data.frame.TrialDesignSet <- function(x, row.names = NULL,
 }
 
 #'
-#' @name TrialDesignSet_plot
-#' 
 #' @title
 #' Trial Design Set Plotting
 #' 
@@ -620,6 +599,9 @@ as.data.frame.TrialDesignSet <- function(x, row.names = NULL,
 #' @param theta A vector of theta values.
 #' @param nMax The maximum sample size.
 #' @param plotPointsEnabled If \code{TRUE}, additional points will be plotted.
+#' @param showSource If \code{TRUE}, the parameter names of the object will 
+#'        be printed which were used to create the plot; that may be, e.g., 
+#'        useful to check the values or to create own plots with \code{\link[graphics]{plot}}.
 #' @param legendPosition The position of the legend. 
 #' By default (\code{NA_integer_}) the algorithm tries to find a suitable position. 
 #' Choose one of the following values to specify the position manually:
@@ -636,12 +618,14 @@ as.data.frame.TrialDesignSet <- function(x, row.names = NULL,
 #' }
 #' @param type The plot type (default = \code{1}). The following plot types are available:
 #' \itemize{
-#'   \item \code{1}: creates a 'Boundary Plot'
-#'   \item \code{2}: creates an 'Average Sample Size and Power / Early Stop' plot
-#'   \item \code{3}: creates a 'Stage Levels Plot'
-#'   \item \code{4}: creates a 'Power' plot
-#'   \item \code{5}: creates a 'Stopping Probability' plot
-#'   \item \code{6}: creates an 'Error Spending Plot'
+#'   \item \code{1}: creates a 'Boundaries' plot
+#'   \item \code{3}: creates a 'Stage Levels' plot
+#'   \item \code{4}: creates a 'Type One Error Spending' plot
+#'   \item \code{5}: creates a 'Power and Early Stopping' plot
+#'   \item \code{6}: creates an 'Average Sample Size and Power / Early Stop' plot
+#'   \item \code{7}: creates an 'Power' plot
+#'   \item \code{8}: creates an 'Early Stopping' plot
+#'   \item \code{9}: creates an 'Average Sample Size' plot
 #' }
 #' @param ... Optional \code{ggplot2} arguments.
 #' 
@@ -669,43 +653,83 @@ as.data.frame.TrialDesignSet <- function(x, row.names = NULL,
 plot.TrialDesignSet <- function(x, y, type = 1L, main = NA_character_, 
 		xlab = NA_character_, ylab = NA_character_, palette = "Set1",
 		theta = seq(-1, 1, 0.02), nMax = NA_integer_, plotPointsEnabled = NA, 
-		legendPosition = NA_integer_, ...) {
-		
+		legendPosition = NA_integer_, showSource = FALSE, ...) {
+	
+	fCall = match.call(expand.dots = FALSE)
+	designSetName <- as.character(fCall$x)[1]	
+	.plotTrialDesignSet(x = x, y = y, type = type, main = main, 
+		xlab = xlab, ylab = ylab, palette = palette,
+		theta = theta, nMax = nMax, plotPointsEnabled = plotPointsEnabled, 
+		legendPosition = legendPosition, showSource = showSource, 
+		designSetName = designSetName, ...)
+}
+
+.plotTrialDesignSet <- function(x, y, type = 1L, main = NA_character_, 
+		xlab = NA_character_, ylab = NA_character_, palette = "Set1",
+		theta = seq(-1, 1, 0.02), nMax = NA_integer_, plotPointsEnabled = NA, 
+		legendPosition = NA_integer_, showSource = FALSE, 
+		designSetName = NA_character_, ...) {
+	
 	.assertGgplotIsInstalled()
 	
 	.assertIsValidLegendPosition(legendPosition)
 	theta <- .assertIsValidThetaRange(thetaRange = theta)
 	
+	parameterSet <- x
+	designMaster <- parameterSet$getDesignMaster()
+	.assertIsTrialDesign(designMaster)
+	
 	if (type == 1) {
-		main <- ifelse(is.na(main), "Boundary Plot", main)
+		main <- ifelse(is.na(main), "Boundaries", main)
 		xParameterName <- "informationRates"
-		if (x$getDesignMaster()$sided == 1 && .isTrialDesignWithValidFutilityBounds(x$getDesignMaster())) {
+		if (designMaster$sided == 1 && .isTrialDesignWithValidFutilityBounds(designMaster)) {
 			yParameterNames <- c("futilityBounds", "criticalValues")
 		} else {
 			yParameterNames <- c("criticalValues")
 		}
 	}
-		
+	
 	else if (type == 2) {
-		if (is.na(main)) {
-			main <- bquote(atop(bold('Average Sample Size and Power / Early Stop'), 
-							atop(bold('(N'['max']*'='*.(nMax)*")"))))
-		}
-		xParameterName <- "theta"
-		yParameterNames <- c("averageSampleNumber", "overallEarlyStop", "calculatedPower")
-	} 
+		stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "designs with undefined endpoint do not support plot type 2")
+	}
 		
 	else if (type == 3) {
-		main <- ifelse(is.na(main), "Stage Levels Plot", main)
+		main <- ifelse(is.na(main), "Stage Levels", main)
 		xParameterName <- "informationRates"
 		yParameterNames <- "stageLevels"
 	} 
 	
 	else if (type == 4) {
-		#eval(expression(Power~( ~ N[max]~ nMax)))
-		#p <- p + ggtitle(bquote(list(alpha==.(alpha), lambda==.(lambda), memory==.(mem))))
-		#p <- p +  ggtitle(bquote(atop(bold(.(title)), atop(.(subtitle)))))
-		#p <- p +  ggtitle(bquote('Assimilation ('*mu~ 'mol' ~CO[2]~ m^-2~s^-1*')'))
+		main <- ifelse(is.na(main), "Type One Error Spending", main)
+		xParameterName <- "informationRates"
+		yParameterNames <- c("alphaSpent")
+		if (designMaster$typeBetaSpending != C_TYPE_OF_DESIGN_BS_NONE) {
+			yParameterNames <- c(yParameterNames, "betaSpent")
+			palette <- "Paired"
+		}
+		plotPointsEnabled <- ifelse(is.na(plotPointsEnabled), FALSE, plotPointsEnabled)
+	}
+	
+	else if (type == 5) {
+		if (is.na(main)) {
+			main <- bquote(atop(bold('Power and Early Stopping'), 
+					atop('(N'['max']*'='*.(nMax)*')')))
+		}
+
+		xParameterName <- "theta"
+		yParameterNames <- c("overallEarlyStop", "calculatedPower")
+	}
+	
+	else if (type == 6) { 
+		if (is.na(main)) {
+			main <- bquote(atop(bold('Average Sample Size and Power / Early Stop'), 
+					atop('(N'['max']*'='*.(nMax)*")")))
+		}
+		xParameterName <- "theta"
+		yParameterNames <- c("averageSampleNumber", "overallEarlyStop", "calculatedPower") 
+	} 
+	
+	else if (type == 7) { 
 		if (is.na(main)) {
 			main <- bquote(atop(bold('Power'), atop('(N'['max']*'='*.(nMax)*")")))
 		}
@@ -713,388 +737,41 @@ plot.TrialDesignSet <- function(x, y, type = 1L, main = NA_character_,
 		yParameterNames <- "calculatedPower"
 	} 
 	
-	else if (type == 5) {
+	else if (type == 8) {
 		if (is.na(main)) {
-			main <- bquote(atop(bold('Stopping Probability'), atop('(N'['max']*'='*.(nMax)*")")))
+			main <- bquote(atop(bold('Early Stopping'), atop('(N'['max']*'='*.(nMax)*")")))
 		}
 		xParameterName <- "theta"
 		yParameterNames <- "overallEarlyStop"
 	} 
 	
-	else if (type == 6) {
-		main <- ifelse(is.na(main), "Error Spending Plot", main)
-		xParameterName <- "informationRates"
-		yParameterNames <- c("alphaSpent")
-		if (x$getDesignMaster()$typeBetaSpending != C_TYPE_OF_DESIGN_BS_NONE) {
-			yParameterNames <- c(yParameterNames, "betaSpent")
-			palette <- "Paired"
+	else if (type == 9) {
+		if (is.na(main)) {
+			main <- bquote(atop(bold('Average Sample Size'), 
+					atop('(N'['max']*'='*.(nMax)*")")))
 		}
-		plotPointsEnabled <- ifelse(is.na(plotPointsEnabled), FALSE, plotPointsEnabled)
+		xParameterName <- "theta"
+		yParameterNames <- "averageSampleNumber" 
 	}
 	
 	else {
-		stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'type' (", type, ") is not allowed; must be 1, 2, ..., 6")
+		stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'type' (", type, ") is not allowed; must be 1, 2, ..., 9")
 	}
 	
-	companyAnnotationEnabled <- .getOptionalArgument("companyAnnotationEnabled", ...)
-	if (is.null(companyAnnotationEnabled) || !is.logical(companyAnnotationEnabled)) {
-		companyAnnotationEnabled <- FALSE
-	}
-	return(.plotTrialDesignSet(designSet = x, xParameterName = xParameterName,
+	.showPlotSourceInformation(objectName = designSetName, 
+		xParameterName = xParameterName, 
+		yParameterNames = yParameterNames, 
+		nMax = nMax,
+		showSource = showSource)
+	
+	return(.plotParameterSet(parameterSet = parameterSet, designMaster = designMaster, 
+		xParameterName = xParameterName,
 		yParameterNames = yParameterNames, mainTitle = main, xlab = xlab, ylab = ylab,
 		palette = palette, theta = theta, nMax = nMax, plotPointsEnabled = plotPointsEnabled,
-		legendPosition = legendPosition,
-		companyAnnotationEnabled = companyAnnotationEnabled))
-}
-
-.getDesignSetAsDataFrame <- function(designSet, 
-		addPowerAndAverageSampleNumber = FALSE, theta = seq(-1, 1, 0.02), nMax = NA_integer_) {
-		
-	if (designSet$getSize() > 1 && (is.null(designSet$variedParameters) || 
-			length(designSet$variedParameters) == 0)) {
-		stop("'variedParameters' must be not empty; ",
-			"use 'DesignSet$addVariedParameters(character)' to add one or more varied parameters")
-	}
-	
-	data <- as.data.frame(designSet, niceColumnNamesEnabled = FALSE, 
-		includeAllParameters = TRUE, addPowerAndAverageSampleNumber = addPowerAndAverageSampleNumber,
-		theta = theta, nMax = nMax)	
-	if (designSet$getSize() <= 1) {
-		return(list(data = data, variedParameters = designSet$variedParameters))
-	}
-	
-	variedParameters <- designSet$variedParameters
-	if (nrow(data) > 1) {
-		for (variedParameter in variedParameters) {
-			column <- data[[variedParameter]]
-			if (length(column) <= 1) {
-				stop("Varied parameter '", variedParameter, "' hast length ", length(column))
-			}
-			
-			valueBefore <- column[1]
-			for (i in 2:length(column)) {
-				if (is.na(column[i])) {
-					column[i] <- valueBefore
-				} else {
-					valueBefore <- column[i]
-				}
-			}
-			data[[variedParameter]] <- column
-		}
-	}
-	variedParameterNames <- c()
-	for (variedParameter in variedParameters) {
-		variedParameterNames <- c(variedParameterNames, 
-			.getTableColumnNames(design = designSet$getDesignMaster())[[variedParameter]])
-	}
-	names(variedParameters) <- variedParameterNames
-	return(list(data = data, variedParameters = variedParameters))
-}
-
-.getCategories <- function(data, yParameterName, tableColumnNames) {
-	if (sum(is.na(data$categories)) > 0) {
-		return(rep(.getAxisLabel(yParameterName, tableColumnNames), nrow(data)))
-	}
-	
-	return(paste(data$categories, .getAxisLabel(yParameterName, tableColumnNames), sep = ", "))
-}
-
-.getAxisLabel <- function(parameterName, tableColumnNames) {
-	return(tableColumnNames[[parameterName]])
-}
-
-.plotTrialDesignSet <- function(designSet, xParameterName, yParameterNames,
-		mainTitle = NA_character_, xlab = NA_character_, ylab = NA_character_, 
-		palette = "Set1", theta = seq(-1, 1, 0.02), nMax = NA_integer_, 
-		plotPointsEnabled = NA, legendPosition = NA_integer_, companyAnnotationEnabled = FALSE) {
-		
-	designSet$assertHaveEqualSidedValues()
-	
-	addPowerAndAverageSampleNumber <- xParameterName == "theta" && 
-		yParameterNames[1] %in% c("averageSampleNumber", "calculatedPower", "overallEarlyStop",
-			"overallRejectPerStage", "overallFutilityPerStage") 
-	df <- .getDesignSetAsDataFrame(designSet, 
-		addPowerAndAverageSampleNumber = addPowerAndAverageSampleNumber, theta = theta, nMax = nMax)
-	data <- df$data	
-	variedParameters <- df$variedParameters
-	
-	legendTitle <- paste(names(variedParameters), collapse = "\n")
-	categoryParameterName <- variedParameters[1]
-	
-	yParameterName1 <- yParameterNames[1]
-	yParameterName2 <- NULL
-	yParameterName3 <- NULL
-	if (length(yParameterNames) >= 2) {
-		yParameterName2 <- yParameterNames[2]
-	}
-	if (length(yParameterNames) >= 3) {
-		yParameterName3 <- yParameterNames[3]
-	}
-	
-	tableColumnNames <- .getTableColumnNames(design = designSet$getDesignMaster())
-	
-	xAxisLabel <- .getAxisLabel(xParameterName, tableColumnNames)
-	yAxisLabel1 <- .getAxisLabel(yParameterName1, tableColumnNames)
-	yAxisLabel2 <- NULL
-	if (!is.null(yParameterName2) && !is.null(yParameterName3)) {
-		pn2 <- .getAxisLabel(yParameterName2, tableColumnNames)
-		if (yParameterName2 == "overallEarlyStop") {
-			pn2 <- "Stopping Probability"
-		}
-		yAxisLabel2 <- paste(pn2, .getAxisLabel(yParameterName3, tableColumnNames), sep = " and ")
-	}
-	else if (!is.null(yParameterName2)) {
-		yAxisLabel1 <- paste(yAxisLabel1, .getAxisLabel(yParameterName2, tableColumnNames), sep = " and ")
-	}
-	if (yParameterName1 %in% c("alphaSpent", "betaSpent")) {
-		yAxisLabel1 <- "Cumulative Error"
-		if (is.null(yParameterName2)) {
-			yAxisLabel1 <- paste0(yAxisLabel1, " (", .getAxisLabel(yParameterName1, tableColumnNames), ")")
-		}
-	}
-	
-	data$xValues <- data[[xParameterName]]
-	data$yValues <- data[[yParameterName1]]
-	if (is.null(yParameterName2)) {
-		data$yValues2 <- rep(NA_real_, nrow(data))
-	} else {
-		data$yValues2 <- data[[yParameterName2]]
-	}
-	if (is.null(yParameterName3)) {
-		data$yValues3 <- rep(NA_real_, nrow(data))
-	} else {
-		data$yValues3 <- data[[yParameterName3]]
-	}
-	
-	if (!is.na(categoryParameterName)) {
-		data$categories <- data[[categoryParameterName]]
-		if (length(variedParameters) > 1) {
-			data$categories <- paste0(variedParameters[1], " = ", data$categories, ", ", 
-				variedParameters[2], " = ", data[[variedParameters[2]]])
-		}
-	} else {
-		data$categories <- rep(NA_character_, nrow(data))
-	}
-	
-	if (!is.na(nMax) && is.null(yParameterName3) && xParameterName == "informationRates") {
-		xAxisLabel <- "Sample Size"
-		data$xValues <- data$xValues * nMax
-	}
-		
-	# add zero point to data
-	if (yParameterName1 %in% c("alphaSpent", "betaSpent")) {
-		data <- data[, c("xValues", "yValues", "yValues2", "categories")]
-		uc <- unique(data$categories)
-		data <- rbind(data.frame(
-			xValues = rep(-0.00001, length(uc)),
-			yValues = rep(0, length(uc)),
-			yValues2 = rep(0, length(uc)),
-			categories = uc
-		), data)
-	}
-
-	scalingFactor1 <- 1
-	scalingFactor2 <- 1
-	if (!is.null(yParameterName2)) {
-		if (!is.null(yParameterName3)) {
-			m1 <- max(data$yValues)
-			m2 <- max(data$yValues2, data$yValues3)
-			if (m1 > m2) {
-				scalingFactor1 <- 1
-				scalingFactor2 <- m1
-			} else if (m1 < m2) {
-				scalingFactor1 <- m2
-				scalingFactor2 <- 1
-			}
-		}
-		df1 <- data.frame(
-			xValues = data$xValues,
-			yValues = data$yValues * scalingFactor1,
-			categories = .getCategories(data, yParameterName1, tableColumnNames)
-		)
-		df2 <- data.frame(
-			xValues = data$xValues,
-			yValues = data$yValues2 * scalingFactor2,
-			categories = .getCategories(data, yParameterName2, tableColumnNames)
-		)
-		if (!is.null(yParameterName3)) {
-			df3 <- data.frame(
-				xValues = data$xValues,
-				yValues = data$yValues3 * scalingFactor2,
-				categories = .getCategories(data, yParameterName3, tableColumnNames)
-			)
-			data <- rbind(df1, df2, df3)
-		} else {
-			data <- rbind(df1, df2)
-		}
-		
-		# sort categories for pairwise printing of the legend
-		unqiueValues <- unique(as.character(data$categories))
-		data$categories <- factor(data$categories, levels = unqiueValues[order(unqiueValues)])
-		
-		if (yParameterName1 == "alphaSpent" && yParameterName2 == "betaSpent") {
-			legendTitle <- paste(legendTitle, "Type of error", sep = "\n")
-		}
-	}
-	
-	numberOfCategories <- 1
-	if (sum(is.na(data$categories)) < length(data$categories)) {
-		numberOfCategories <- length(unique(as.character(data$categories)))
-	}
-	
-	nRow <- nrow(data)
-	data <- data[!(data$xValues == 0 & data$xValues == data$yValues), ]
-	removedRows1 <- nRow - nrow(data)
-	
-	nRow <- nrow(data)
-	data <- data[!is.na(data$yValues), ]
-	removedRows2 <- nRow - nrow(data)
-	
-	if (C_LOG_LEVEL == C_LOG_LEVEL_WARN && (removedRows1 > 0 || removedRows2 > 0)) {
-		warning(sprintf("Removed %s rows containing (0, 0)-points and %s rows containing missing values", 
-				removedRows1, removedRows2), call. = FALSE)
-	}
-	
-	categoryEnabled <- (sum(is.na(data$categories)) < length(data$categories))
-	
-	if (categoryEnabled) {
-		data <- data[, c("xValues", "yValues", "categories")]
-	} else {
-		data <- data[, c("xValues", "yValues")]
-	}
-	
-	if (categoryEnabled) {	
-		p <- ggplot2::ggplot(data, ggplot2::aes(x = data$xValues, y = data$yValues, 
-				colour = factor(data$categories)))
-	} else {
-		p <- ggplot2::ggplot(data, ggplot2::aes(x = data$xValues, y = data$yValues))
-	}
-			
-	p <- designSet$getPlotSettings()$setTheme(p)
-	p <- designSet$getPlotSettings()$hideGridLines(p)
-	
-	# set main title
-	p <- designSet$getPlotSettings()$setMainTitle(p, mainTitle)
-	
-	# set legend
-	if (!is.na(legendPosition) && legendPosition == -1) {
-		p <- p + ggplot2::theme(legend.position = "none")
-	} else if (categoryEnabled) {
-		if (is.na(legendPosition)) {
-			legendPosition <- .getLegendPosition(designSet, data, yParameterName1, 
-				yParameterName2, addPowerAndAverageSampleNumber)
-		}
-		p <- designSet$getPlotSettings()$setLegendPosition(p, legendPosition = legendPosition)
-		p <- designSet$getPlotSettings()$setLegendBorder(p)
-		p <- designSet$getPlotSettings()$setLegendTitle(p, legendTitle)
-		p <- designSet$getPlotSettings()$setLegendLabelSize(p)
-	}
-	
-	xAxisLabel <- .toCapitalized(xAxisLabel)
-	yAxisLabel1 <- .toCapitalized(yAxisLabel1)
-	yAxisLabel2 <- .toCapitalized(yAxisLabel2)
-	
-	p <- designSet$getPlotSettings()$setAxesLabels(p, 
-		xAxisLabel = xAxisLabel, yAxisLabel1 = yAxisLabel1, yAxisLabel2 = yAxisLabel2, 
-		xlab = xlab, ylab = ylab, scalingFactor1 = scalingFactor1, scalingFactor2 = scalingFactor2)
-	
-	# plot lines and points
-	plotPointsEnabled <- ifelse(is.na(plotPointsEnabled), !addPowerAndAverageSampleNumber, plotPointsEnabled) 
-	pointBorder <- 4
-	if (numberOfCategories > 8) {
-		pointBorder <- 1
-	}
-	else if (numberOfCategories > 6) {
-		pointBorder <- 2
-	}
-	else if (numberOfCategories > 4) {
-		pointBorder <- 3
-	}
-	p <- designSet$getPlotSettings()$plotValues(p, plotPointsEnabled = plotPointsEnabled, pointBorder = pointBorder)
-	
-	if (yParameterName1 == "criticalValues" && designSet$getDesignMaster()$sided == 2) {
-		p <- designSet$getPlotSettings()$mirrorYValues(p, yValues = data$yValues, 
-			plotPointsEnabled = !addPowerAndAverageSampleNumber, pointBorder = pointBorder)
-	}
-	
-	if (yParameterName1 == "criticalValues" || 
-			(yParameterName1 == "futilityBounds" && yParameterName2 == "criticalValues")) {
-		p <- .addQnormAlphaLine(p, designSet, data)
-	}
-	
-	p <- designSet$getPlotSettings()$setAxesAppearance(p)
-	p <- designSet$getPlotSettings()$setColorPalette(p, palette)
-	p <- designSet$getPlotSettings()$enlargeAxisTicks(p)
-	
-	p <- designSet$getPlotSettings()$addCompanyAnnotation(p, enabled = companyAnnotationEnabled)
-	
-	# start plot generation
-	return(p)
-}
-
-.getLegendPosition <- function(designSet, data, yParameterName1, 
-		yParameterName2, addPowerAndAverageSampleNumber) {
-		
-	if (length(unique(data$categories)) > 6) {
-		designSet$getPlotSettings()$adjustPointSize(-0.5)
-		designSet$getPlotSettings()$adjustLegendFontSize(-2)
-		return(C_POSITION_OUTSIDE_PLOT)
-	}
-	
-	if (.isTrialDesignWithValidFutilityBounds(designSet$getDesignMaster()) &&
-		yParameterName1 == "futilityBounds" && yParameterName2 == "criticalValues") {
-		return(C_POSITION_RIGHT_BOTTOM)
-	}
-
-	if (yParameterName1 == "criticalValues") {
-		return(C_POSITION_RIGHT_TOP)
-	} 
-	
-	if (yParameterName1 %in% c("stageLevels", "alphaSpent", "betaSpent")) {
-		return(C_POSITION_LEFT_TOP)
-	}
-	
-	if (addPowerAndAverageSampleNumber) {
-		return(C_POSITION_LEFT_CENTER)
-	}
-	
-	return(C_POSITION_OUTSIDE_PLOT)
-} 
-
-.addQnormAlphaLine <- function(p, designSet, data, annotationEnabled = TRUE) {
-	alpha <- designSet$getDesignMaster()$alpha
-	if (designSet$getDesignMaster()$sided == 2) {
-		alpha <- alpha / 2
-	}
-	yValue <- stats::qnorm(1 - alpha)
-	yValueLabel <- paste0("qnorm(1 - ", alpha, " ) == ", round(yValue, 4))
-	if (designSet$getDesignMaster()$sided == 1) {
-		p <- p + ggplot2::geom_hline(yintercept = yValue, linetype = "dashed") 
-	} else {
-		p <- p + ggplot2::geom_hline(yintercept = yValue, linetype = "dashed")
-		p <- p + ggplot2::geom_hline(yintercept = -yValue, linetype = "dashed")
-	}
-	if (annotationEnabled) {
-		p <- p + ggplot2::annotate("label", x = -Inf, hjust = -0.1, y = yValue, 
-			label = yValueLabel, size = 2.5, parse = TRUE, colour = "white", fill = "white")
-		p <- p + ggplot2::annotate("text", x = -Inf, hjust = -0.15, y = yValue, 
-			label = yValueLabel, size = 2.5, parse = TRUE)
-	}
-	
-	# expand y-axis range
-	if (designSet$getDesignMaster()$sided == 1) {
-		
-		yMax <- max(stats::na.omit(data$yValues))
-		if (!is.null(data$yValues2) && length(data$yValues2) > 0) {
-			yMax <- max(yMax, stats::na.omit(data$yValues2))
-		}
-		eps <- (yMax - yValue) * 0.15
-		
-		p <- designSet$getPlotSettings()$expandAxesRange(p, y = yValue - eps)
-	}
-	
-	return(p)
+		legendPosition = legendPosition, ...))
 }
 
 
 
+
+
